to_bytes

Function to_bytes 

pub fn to_bytes(value: &Value) -> Vec<u8> 
Serialize a serde_json::Value to canonical bytes (SPEC 5).

Infallible: serde_json::Value cannot hold NaN / ±Infinity, so the only way a number is un-representable has already been ruled out before this function is called.